@@ -62,11 +62,11 @@ module Shm = struct
 end
 
 (* feeder process loop *)
-let feed_them_all csize ncores demux queue =
+let feed_them_all tmp csize ncores demux queue =
   (* let pid = Unix.getpid () in
    * eprintf "feeder(%d) started\n%!" pid; *)
   let in_count = ref 0 in
-  let prfx = Filename.temp_file "iparany_" "" in
+  let prfx = Filename.temp_file ~temp_dir:tmp "iparany_" "" in
   let to_send = ref [] in
   try
     while true do
@@ -158,6 +158,12 @@ let imux (mux: 'b -> unit) =
       (* put somewhere into the pile *)
       Ht.add wait_list i res
 
+(* once initialized, my_rank will be in [0:ncores-1] *)
+let my_rank = ref (-1)
+
+let get_rank () =
+  !my_rank
+
 let run ?(init = fun (_rank: int) -> ()) ?(finalize = fun () -> ())
     ?(preserve = false) ?(core_pin = false) ?(csize = 1) nprocs
     ~demux ~work ~mux =
@@ -171,9 +177,11 @@ let run ?(init = fun (_rank: int) -> ()) ?(finalize = fun () -> ())
     (* eprintf "father(%d) starting feeder\n%!" pid; *)
     flush_all (); (* prevent duplicated I/O *)
     Gc.compact (); (* like parmap: reclaim memory prior to forking *)
-    fork_out (fun () -> feed_them_all csize nprocs demux jobs_in);
+    let tmp = Filename.get_temp_dir_name () in
+    fork_out (fun () -> feed_them_all tmp csize nprocs demux jobs_in);
     (* start workers *)
     for worker_rank = 0 to nprocs - 1 do
+      my_rank := worker_rank;
       (* eprintf "father(%d) starting a worker\n%!" pid; *)
       fork_out (fun () ->
           init worker_rank; (* per-process optional setup *)
@@ -181,7 +189,7 @@ let run ?(init = fun (_rank: int) -> ()) ?(finalize = fun () -> ())
           (* parmap also does core pinning _after_ having called
              the per-process init function *)
           if core_pin then Cpu.setcore worker_rank;
-          let prfx = Filename.temp_file "oparany_" "" in
+          let prfx = Filename.temp_file ~temp_dir:tmp "oparany_" "" in
           at_exit (fun () ->
               (* tell collector to stop *)
               (* eprintf "worker(%d) finished\n%!" pid; *)
